Canvas

Struct Canvas 

pub struct Canvas { /* private fields */ }
The Canvas LMS API client. All interaction starts here.

Example

let canvas = canvas_lms_api::Canvas::new("https://canvas.example.edu", "my-token")?;
let course = canvas.get_course(1).await?;
println!("{}", course.name.unwrap_or_default());

Implementations

Source

impl Canvas

pub fn new(base_url: &str, access_token: &str) -> Result<Self>

Create a new Canvas client.

base_url should be the institution root (e.g. https://canvas.example.edu), not including /api/v1.

pub fn with_client( base_url: &str, access_token: &str, client: Client, ) -> Result<Self>

Create a Canvas client with a custom reqwest::Client (for proxy, TLS config, etc.).

pub async fn get_course(&self, course_id: u64) -> Result<Course>

Fetch a single course by ID.

Canvas API

GET /api/v1/courses/:id

pub fn get_courses(&self) -> PageStream<Course>

Stream all courses visible to the authenticated user.

Canvas API

GET /api/v1/courses

pub async fn create_course( &self, account_id: u64, params: CreateCourseParams, ) -> Result<Course>

Create a new course under an account.

Canvas API

POST /api/v1/accounts/:account_id/courses

pub async fn delete_course(&self, course_id: u64) -> Result<Course>

Delete a course by ID. Canvas returns the deleted course object.

Canvas API

DELETE /api/v1/courses/:id

pub async fn get_user(&self, user_id: UserId) -> Result<User>

Fetch a single user by ID or UserId::Current for the authenticated user.

Canvas API

GET /api/v1/users/:id

pub async fn get_current_user(&self) -> Result<CurrentUser>

Fetch the currently authenticated user.

Canvas API

GET /api/v1/users/self

pub async fn create_user( &self, account_id: u64, params: CreateUserParams, ) -> Result<User>

Create a new user under an account.

Canvas API

POST /api/v1/accounts/:account_id/users

pub async fn get_account(&self, account_id: u64) -> Result<Account>

Fetch a single account by ID.

Canvas API

GET /api/v1/accounts/:id

pub async fn get_outcome(&self, outcome_id: u64) -> Result<Outcome>

Fetch a single outcome by ID.

Canvas API

GET /api/v1/outcomes/:id

pub fn get_accounts(&self) -> PageStream<Account>

Stream all accounts accessible to the authenticated user.

Canvas API

GET /api/v1/accounts

pub async fn get_section(&self, section_id: u64) -> Result<Section>

Fetch a single section by ID.

Canvas API

GET /api/v1/sections/:id

pub async fn get_group(&self, group_id: u64) -> Result<Group>

Fetch a single group by ID.

Canvas API

GET /api/v1/groups/:id

pub async fn get_file(&self, file_id: u64) -> Result<File>

Fetch a single file by ID.

Canvas API

GET /api/v1/files/:id

pub async fn get_folder(&self, folder_id: u64) -> Result<Folder>

Fetch a single folder by ID.

Canvas API

GET /api/v1/folders/:id

pub async fn get_progress(&self, progress_id: u64) -> Result<Progress>

Fetch a single progress object by ID.

Canvas API

GET /api/v1/progress/:id

pub async fn get_conversation( &self, conversation_id: u64, ) -> Result<Conversation>

Fetch a single conversation by ID.

Canvas API

GET /api/v1/conversations/:id

pub fn get_conversations(&self) -> PageStream<Conversation>

Stream all conversations for the authenticated user.

Canvas API

GET /api/v1/conversations

pub async fn create_conversation( &self, recipients: &[&str], body: &str, params: ConversationParams, ) -> Result<Conversation>

Create a new conversation.

Canvas API

POST /api/v1/conversations

pub async fn get_calendar_event(&self, event_id: u64) -> Result<CalendarEvent>

Fetch a single calendar event by ID.

Canvas API

GET /api/v1/calendar_events/:id

pub fn get_calendar_events(&self) -> PageStream<CalendarEvent>

Stream all calendar events visible to the authenticated user.

Canvas API

GET /api/v1/calendar_events

pub async fn create_calendar_event( &self, context_code: &str, params: CalendarEventParams, ) -> Result<CalendarEvent>

Create a new calendar event.

Canvas API

POST /api/v1/calendar_events

pub async fn get_planner_note(&self, note_id: u64) -> Result<PlannerNote>

Fetch a single planner note by ID.

Canvas API

GET /api/v1/planner_notes/:id

pub fn get_planner_notes(&self) -> PageStream<PlannerNote>

Stream all planner notes for the authenticated user.

Canvas API

GET /api/v1/planner_notes

pub async fn create_planner_note( &self, params: PlannerNoteParams, ) -> Result<PlannerNote>

Create a planner note for the authenticated user.

Canvas API

POST /api/v1/planner_notes

pub async fn get_planner_override( &self, override_id: u64, ) -> Result<PlannerOverride>

Fetch a single planner override by ID.

Canvas API

GET /api/v1/planner/overrides/:id

pub fn get_planner_overrides(&self) -> PageStream<PlannerOverride>

Stream all planner overrides for the authenticated user.

Canvas API

GET /api/v1/planner/overrides

pub async fn create_planner_override( &self, plannable_type: &str, plannable_id: u64, ) -> Result<PlannerOverride>

Create a planner override for a specific plannable item.

Canvas API

POST /api/v1/planner/overrides

pub async fn get_eportfolio(&self, eportfolio_id: u64) -> Result<EPortfolio>

Fetch a single ePortfolio by ID.

Canvas API

GET /api/v1/eportfolios/:id

pub async fn get_appointment_group( &self, group_id: u64, ) -> Result<AppointmentGroup>

Fetch a single appointment group by ID.

Canvas API

GET /api/v1/appointment_groups/:id

pub fn get_appointment_groups(&self) -> PageStream<AppointmentGroup>

Stream all appointment groups visible to the authenticated user.

Canvas API

GET /api/v1/appointment_groups

pub async fn create_appointment_group( &self, params: AppointmentGroupParams, ) -> Result<AppointmentGroup>

Create a new appointment group.

Canvas API

POST /api/v1/appointment_groups

pub async fn get_poll(&self, poll_id: u64) -> Result<Poll>

Fetch a single poll by ID.

Canvas API

GET /api/v1/polls/:id

pub fn get_polls(&self) -> PageStream<Poll>

Stream all polls for the current user.

Canvas API

GET /api/v1/polls

pub async fn create_poll(&self, params: CreatePollParams) -> Result<Poll>

Create a new poll for the current user.

Canvas API

POST /api/v1/polls

pub async fn create_jwt(&self) -> Result<CanvasJwt>

Create a short-lived JWT for use with other Canvas services.

Canvas API

POST /api/v1/jwts

pub async fn refresh_jwt(&self, token: &str) -> Result<CanvasJwt>

Refresh an existing JWT, returning a new one.

Canvas API

POST /api/v1/jwts/refresh