pub struct FeatureFlag {
pub feature: Option<String>,
pub context_type: Option<String>,
pub context_id: Option<u64>,
pub state: Option<String>,
pub locked: Option<bool>,
pub transitions: Option<Value>,
/* private fields */
}Expand description
The state of a feature flag for a particular context (account, course, or user).
Fields
feature: Option<String>context_type: Option<String>context_id: Option<u64>state: Option<String>One of: "on", "off", "allowed", "allowed_on", "hidden"
locked: Option<bool>transitions: Option<Value>Implementations
Sourceimpl FeatureFlag
impl FeatureFlag
Sourcepub async fn delete(&self) -> Result<FeatureFlag>
pub async fn delete(&self) -> Result<FeatureFlag>
Remove this feature flag, reverting to the inherited value.
Canvas API
DELETE /api/v1/:context_type/:context_id/features/flags/:feature
Sourcepub async fn set_feature_flag(&self, state: &str) -> Result<FeatureFlag>
pub async fn set_feature_flag(&self, state: &str) -> Result<FeatureFlag>
Set this feature flag to the given state.
state must be one of: "on", "off", "allowed", "allowed_on", "hidden".
Canvas API
PUT /api/v1/:context_type/:context_id/features/flags/:feature